grib2io.tables.originating_centers API documentation

# grib2io.tables.originating_centers

View Source

      1_ncep_grib2_table_version = '36.0.0'
      2
      3table_originating_centers  = {
      4'1':'Melbourne',
      5'2':'Melbourne',
      6'3':'Melbourne',
      7'4':'Moscow',
      8'5':'Moscow',
      9'6':'Moscow',
     10'7':'US National Weather Service - NCEP',
     11'8':'US National Weather Service Telecommunications Gateway (NWSTG)',
     12'9':'US National Weather Service - Other',
     13'10':'Cairo (RSMC)',
     14'11':'Cairo (RSMC)',
     15'12':'Dakar (RSMC)',
     16'13':'Dakar (RSMC)',
     17'14':'Nairobi (RSMC)',
     18'15':'Nairobi (RSMC)',
     19'16':'Casablanca (RSMC)',
     20'17':'Tunis (RSMC)',
     21'18':'Tunis-Casablanca (RSMC)',
     22'19':'Tunis-Casablanca (RSMC)',
     23'20':'Las Palmas',
     24'21':'Algiers (RSMC)',
     25'22':'ACMAD',
     26'23':'Mozambique (NMC)',
     27'24':'Pretoria (RSMC)',
     28'25':'La Réunion (RSMC)',
     29'26':'Khabarovsk (RSMC)',
     30'27':'Khabarovsk (RSMC)',
     31'28':'New Delhi (RSMC)',
     32'29':'New Delhi (RSMC)',
     33'30':'Novosibirsk (RSMC)',
     34'31':'Novosibirsk (RSMC)',
     35'32':'Tashkent (RSMC)',
     36'33':'Jeddah (RSMC)',
     37'34':'Tokyo (RSMC), Japan Meteorological Agency',
     38'35':'Tokyo (RSMC), Japan Meteorological Agency',
     39'36':'Bangkok',
     40'37':'Ulaanbaatar',
     41'38':'Beijing (RSMC)',
     42'39':'Beijing (RSMC)',
     43'40':'Seoul',
     44'41':'Buenos Aires (RSMC)',
     45'42':'Buenos Aires (RSMC)',
     46'43':'Brasilia (RSMC)',
     47'44':'Brasilia (RSMC)',
     48'45':'Santiago',
     49'46':'Brazilian Space Agency - INPE',
     50'47':'Colombia (NMC)',
     51'48':'Ecuador (NMC)',
     52'49':'Peru (NMC)',
     53'50':'Venezuela (Bolivarian Republic of) (NMC)',
     54'51':'Miami (RSMC)',
     55'52':'Miami (RSMC), National Hurricane Center',
     56'53':'MSC Monitoring',
     57'54':'Montreal (RSMC)',
     58'55':'San Francisco',
     59'56':'ARINC Center',
     60'57':'US Air Force - Air Force Global Weather Center',
     61'58':'Fleet Numerical Meteorology and Oceanography Center, Monterey, CA, US',
     62'59':'The NOAA Forecast Systems Laboratory, Boulder, CO, US',
     63'60':'United States National Center for Atmospheric Research (NCAR)',
     64'61':'Service ARGOS - Landover',
     65'62':'US Naval Oceanographic Office',
     66'63':'International Research Institute for Climate and Society (IRI)',
     67'64':'Honolulu (RSMC)',
     68'65':'Darwin (RSMC)',
     69'66':'Darwin (RSMC)',
     70'67':'Melbourne (RSMC)',
     71'68':'Reserved',
     72'69':'Wellington (RSMC)',
     73'70':'Wellington (RSMC)',
     74'71':'Nadi (RSMC)',
     75'72':'Singapore',
     76'73':'Malaysia (NMC)',
     77'74':'UK Meteorological Office - Exeter (RSMC)',
     78'75':'UK Meteorological Office - Exeter (RSMC)',
     79'76':'Moscow (RSMC)',
     80'77':'Reserved',
     81'78':'Offenbach (RSMC)',
     82'79':'Offenbach (RSMC)',
     83'80':'Rome (RSMC)',
     84'81':'Rome (RSMC)',
     85'82':'Norrköping',
     86'83':'Norrköping',
     87'84':'Toulouse (RSMC)',
     88'85':'Toulouse (RSMC)',
     89'86':'Helsinki',
     90'87':'Belgrade',
     91'88':'Oslo',
     92'89':'Prague',
     93'90':'Episkopi',
     94'91':'Ankara',
     95'92':'Frankfurt/Main',
     96'93':'London (WAFC)',
     97'94':'Copenhagen',
     98'95':'Rota',
     99'96':'Athens',
    100'97':'European Space Agency (ESA)',
    101'98':'European Center for Medium-Range Weather Forecasts (ECMWF) (RSMC)',
    102'99':'De Bilt',
    103'100':'Brazzaville',
    104'101':'Abidjan',
    105'102':'Libya (NMC)',
    106'103':'Madagascar (NMC)',
    107'104':'Mauritius (NMC)',
    108'105':'Niger (NMC)',
    109'106':'Seychelles (NMC)',
    110'107':'Uganda (NMC)',
    111'108':'United Republic of Tanzania (NMC)',
    112'109':'Zimbabwe (NMC)',
    113'110':'Hong Kong, China',
    114'111':'Afghanistan (NMC)',
    115'112':'Bahrain (NMC)',
    116'113':'Bangladesh (NMC)',
    117'114':'Bhutan (NMC)',
    118'115':'Cambodia (NMC)',
    119'116':'Democratic Peoples Republic of Korea (NMC)',
    120'117':'Islamic Republic of Iran (NMC)',
    121'118':'Iraq (NMC)',
    122'119':'Kazakhstan (NMC)',
    123'120':'Kuwait (NMC)',
    124'121':'Kyrgyzstan (NMC)',
    125'122':'Lao Peoples Democratic Republic (NMC)',
    126'123':'Macao, China',
    127'124':'Maldives (NMC)',
    128'125':'Myanmar (NMC)',
    129'126':'Nepal (NMC)',
    130'127':'Oman (NMC)',
    131'128':'Pakistan (NMC)',
    132'129':'Qatar (NMC)',
    133'130':'Yemen (NMC)',
    134'131':'Sri Lanka (NMC)',
    135'132':'Tajikistan (NMC)',
    136'133':'Turkmenistan (NMC)',
    137'134':'United Arab Emirates (NMC)',
    138'135':'Uzbekistan (NMC)',
    139'136':'Vietnam (NMC)',
    140'137-139':'Reserved',
    141'140':'Bolivia (Plurinational State of) (NMC)',
    142'141':'Guyana (NMC)',
    143'142':'Paraguay (NMC)',
    144'143':'Suriname (NMC)',
    145'144':'Uruguay (NMC)',
    146'145':'French Guiana',
    147'146':'Brazilian Navy Hydrographic Center',
    148'147':'National Commission on Space Activities (CONAE) - Argentina',
    149'148':'Brazilian Department of Airspace Control - DECEA',
    150'149':'Reserved',
    151'150':'Antigua and Barbuda (NMC)',
    152'151':'Bahamas (NMC)',
    153'152':'Barbados (NMC)',
    154'153':'Belize (NMC)',
    155'154':'British Caribbean Territories Center',
    156'155':'San José',
    157'156':'Cuba (NMC)',
    158'157':'Dominica (NMC)',
    159'158':'Dominican Republic (NMC)',
    160'159':'El Salvador (NMC)',
    161'160':'US NOAA/NESDIS',
    162'161':'US NOAA Office of Oceanic and Atmospheric Research',
    163'162':'Guatemala (NMC)',
    164'163':'Haiti (NMC)',
    165'164':'Honduras (NMC)',
    166'165':'Jamaica (NMC)',
    167'166':'Mexico City',
    168'167':'Curaçao and Sint Maarten (NMC)',
    169'168':'Nicaragua (NMC)',
    170'169':'Panama (NMC)',
    171'170':'Saint Lucia (NMC)',
    172'171':'Trinidad and Tobago (NMC)',
    173'172':'French Departments in RA IV',
    174'173':'US National Aeronautics and Space Administration (NASA)',
    175'174':'Integrated System Data Management/ Marine Environmental Data Service (ISDM/MEDS) - Canada',
    176'175':'University Corporation for Atmospheric Research (UCAR) - US',
    177'176':'Cooperative Institude for Meteorological Satellite Studies (CIMMS) - US',
    178'177':'NOAA National Ocean Service - US',
    179'178':'Spire Global, Inc.',
    180'179':'GeoOptics, Inc.',
    181'180':'PlanetiQ',
    182'181':'Atmospheric and Environmental Research (AER)',
    183'182':'tomorrow.io',
    184'183':'Scripps Institute of Oceanography (UC San Diego - US)',
    185'184-189':'Reserved',
    186'190':'Cook Islands (NMC)',
    187'191':'French Polynesia (NMC)',
    188'192':'Tonga (NMC)',
    189'193':'Vanuatu (NMC)',
    190'194':'Brunei Darussalam (NMC)',
    191'195':'Indonesia (NMC)',
    192'196':'Kiribati (NMC)',
    193'197':'Federated States of Micronesia (NMC)',
    194'198':'New Caledonia (NMC)',
    195'199':'Niue',
    196'200':'Papua New Guinea (NMC)',
    197'201':'Philippines (NMC)',
    198'202':'Samoa (NMC)',
    199'203':'Solomon Islands (NMC)',
    200'204':'National Institude of Water and Atmospheric Research (NIWA - New Zealand)',
    201'205-209':'Reserved',
    202'210':'Frascati (ESA/ESRIN)',
    203'211':'Lannion',
    204'212':'Lisbon',
    205'213':'Reykjavik',
    206'214':'Madrid',
    207'215':'Zurich',
    208'216':'Service ARGOS - Toulouse',
    209'217':'Bratislava',
    210'218':'Budapest',
    211'219':'Ljubljana',
    212'220':'Warsaw',
    213'221':'Zagreb',
    214'222':'Albania (NMC)',
    215'223':'Armenia (NMC)',
    216'224':'Austria (NMC)',
    217'225':'Azerbaijan (NMC)',
    218'226':'Belarus (NMC)',
    219'227':'Belgium (NMC)',
    220'228':'Bosnia and Herzegovina (NMC)',
    221'229':'Bulgaria (NMC)',
    222'230':'Cyprus (NMC)',
    223'231':'Estonia (NMC)',
    224'232':'Georgia (NMC)',
    225'233':'Dublin',
    226'234':'Israel (NMC)',
    227'235':'Jordan (NMC)',
    228'236':'Latvia (NMC)',
    229'237':'Lebanon (NMC)',
    230'238':'Lithuania (NMC)',
    231'239':'Luxembourg',
    232'240':'Malta (NMC)',
    233'241':'Monaco',
    234'242':'Romania (NMC)',
    235'243':'Syrian Arab Republic (NMC)',
    236'244':'The former Yugoslav Republic of Macedonia (NMC)',
    237'245':'Ukraine (NMC)',
    238'246':'Republic of Moldova (NMC)',
    239'247':'Operational Programme for the Exchange of weather RAdar information (OPERA) - EUMETNET',
    240'248':'Montenegro (NMC)',
    241'249':'Barcelona Dust Forecast Center',
    242'250':'COnsortium for Small scale MOdelling (COSMO)',
    243'251':'Meteorological Cooperation on Operational NWP (MetCoOp)',
    244'252':'Max Planck Institute for Meteorology (MPI-M)',
    245'253':'Alfred Wegener Institute',
    246'254':'EUMETSAT Operation Center',
    247'255':'Not to be Used',
    248'256':'Angola (NMC)',
    249'257':'Benin (NMC)',
    250'258':'Botswana (NMC)',
    251'259':'Burkina Faso (NMC)',
    252'260':'Burundi (NMC)',
    253'261':'Cameroon (NMC)',
    254'262':'Cabo Verde (NMC)',
    255'263':'Central African Republic (NMC)',
    256'264':'Chad (NMC)',
    257'265':'Comoros (NMC)',
    258'266':'Democratic Republic of the Congo (NMC)',
    259'267':'Djibouti (NMC)',
    260'268':'Eritrea (NMC)',
    261'269':'Ethiopia (NMC)',
    262'270':'Gabon (NMC)',
    263'271':'The Gambia (NMC)',
    264'272':'Ghana (NMC)',
    265'273':'Guinea (NMC)',
    266'274':'Guinea-Bissau (NMC)',
    267'275':'Lesotho (NMC)',
    268'276':'Liberia (NMC)',
    269'277':'Malawi (NMC)',
    270'278':'Mali (NMC)',
    271'279':'Mauritania (NMC)',
    272'280':'Namibia (NMC)',
    273'281':'Nigeria (NMC)',
    274'282':'Rwanda (NMC)',
    275'283':'São Tomé and Príncipe (NMC)',
    276'284':'Sierra Leone (NMC)',
    277'285':'Somalia (NMC)',
    278'286':'Sudan (NMC)',
    279'287':'Eswatini (NMC)',
    280'288':'Togo (NMC)',
    281'289':'Zambia (NMC)',
    282'290':'EUMETNET E-Profile',
    283'291':'Institute of Atmospheric Physics (IAP) of the Chinese Academy of Sciences (CAS)',
    284'292':'Helmholtz Centre for Environmental Research (UFZ)',
    285'293':'University of Bremen',
    286'294':'Netherlands Institute for Space Research (SRON)',
    287'295':'Royal Belgian Institute for Space Aeronomy (BIRA-IASB)',
    288'296':'French National Centre for Scientific Research (CNRS)',
    289'297':'Nanjing Institute of Environmental Sciences (NIES)',
    290'298':'Dynamic Meteorology Laboratory (LMD)',
    291'299':'The Rutherford Appleton Laboratory (RAL)',
    292'300':'Greek Atomic Energy Commission (Greece)',
    293'301':'United States Environmental Protection Agency (USA)',
    294'302':'Australian Radiation Protection and Nuclear Safety (Australia)',
    295'303':'Authority for Nuclear Safety and Radiation Protection (Kingdom of the Netherlands)',
    296'304':'Autorité de sûreté nucléaire (France)',
    297'305':'Bundesamt für Strahlenschutz (Germany)',
    298'306':'National Commission for Nuclear Activities Control (Romania)',
    299'307':'Consejo de Seguridad Nuclear (Spain)',
    300'308':'Danish Emergency Management Agency (Denmark)',
    301'309':'Norwegian Radiation Protection Agency (Norway)',
    302'310':'Federal Agency for Nuclear Control (Belgium)',
    303'311':'Institute of Radiation Protection and Dosimetry (Brazil)',
    304'312':'National Inspectorate for Nuclear Safety and Radiation Protection (Italy)',
    305'313':'Nuclear Regulatory Authority (Turkey)',
    306'314':'Nuclear Regulation Authority (Japan)',
    307'315':'Nuclear Regulatory Authority (Bulgaria)',
    308'316':'Ukrainian Radiation Protection Institute (Ukraine)',
    309'317':'Health Canada Radio Protection Bureau (Canada)',
    310'318':'Portuguese Society for Radiation Protection (Portugal)',
    311'319':'Swedish Radiation Safety Authority (Sweden)',
    312'320':'Radiation and Nuclear Safety Authority (Finland)',
    313'321':'State Office for Nuclear Safety (Czech Republic)',
    314'322':'Nuclear Regulation Authority (Slovakia)',
    315'323-65534':'Reserved',
    316'65535':'Missing Value',
    317}
    318
    319table_originating_subcenters  = {
    320'1':'NCEP Re-Analysis Project',
    321'2':'NCEP Ensemble Products',
    322'3':'NCEP Central Operations',
    323'4':'Environmental Modeling Center',
    324'5':'Weather Prediction Center',
    325'6':'Ocean Prediction Center',
    326'7':'Climate Prediction Center',
    327'8':'Aviation Weather Center',
    328'9':'Storm Prediction Center',
    329'10':'National Hurricane Center',
    330'11':'NWS Techniques Development Laboratory',
    331'12':'NESDIS Office of Research and Applications',
    332'13':'Federal Aviation Administration',
    333'14':'NWS Meteorological Development Laboratory',
    334'15':'North American Regional Reanalysis Project',
    335'16':'Space Weather Prediction Center',
    336'17':'ESRL Global Systems Division',
    337'18':'National Water Center',
    338}
    339
    340table_generating_process  = {
    341'0-1':'Reserved',
    342'2':'Ultra Violet Index Model',
    343'3':'NCEP/ARL Transport and Dispersion Model',
    344'4':'NCEP/ARL Smoke Model',
    345'5':'Satellite Derived Precipitation and temperatures, from IR (See PDS Octet 41 ... for specific satellite ID)',
    346'6':'NCEP/ARL Dust Model',
    347'7-9':'Reserved',
    348'10':'Global Wind-Wave Forecast Model',
    349'11':'Global Multi-Grid Wave Model (Static Grids)',
    350'12':'Probabilistic Storm Surge (P-Surge)',
    351'13':'Hurricane Multi-Grid Wave Model',
    352'14':'Extra-tropical Storm Surge Atlantic Domain',
    353'15':'Nearshore Wave Prediction System (NWPS)',
    354'16':'Extra-Tropical Storm Surge (ETSS)',
    355'17':'Extra-tropical Storm Surge Pacific Domain',
    356'18':'Probabilistic Extra-Tropical Storm Surge (P-ETSS)',
    357'19':'Reserved',
    358'20':'Extra-tropical Storm Surge Micronesia Domain',
    359'21':'Extra-tropical Storm Surge Atlantic Domain (3D)',
    360'22':'Extra-tropical Storm Surge Pacific Domain (3D)',
    361'23':'Extra-tropical Storm Surge Micronesia Domain (3D)',
    362'24':'Reserved',
    363'25':'Snow Cover Analysis',
    364'26-29':'Reserved',
    365'30':'Forecaster generated field',
    366'31':'Value added post processed field',
    367'32-41':'Reserved',
    368'42':'Global Optimum Interpolation Analysis (GOI) from GFS model',
    369'43':'Global Optimum Interpolation Analysis (GOI) from "Final" run',
    370'44':'Sea Surface Temperature Analysis',
    371'45':'Coastal Ocean Circulation Model',
    372'46':'HYCOM - Global',
    373'47':'HYCOM - North Pacific basin',
    374'48':'HYCOM - North Atlantic basin',
    375'49':'Ozone Analysis from TIROS Observations',
    376'50-51':'Reserved',
    377'52':'Ozone Analysis from Nimbus 7 Observations',
    378'53':'Flood Hazard Outlook Forecast generated by NWC',
    379'54':'Area Hydrologic Discussion Forecast generated by NWC',
    380'55-63':'Reserved',
    381'64':'Regional Optimum Interpolation Analysis (ROI)',
    382'65-67':'Reserved',
    383'68':'80 wave triangular, 18-layer Spectral model from GFS model',
    384'69':'80 wave triangular, 18 layer Spectral model from "Medium Range Forecast" run',
    385'70':'Quasi-Lagrangian Hurricane Model (QLM)',
    386'71':'Hurricane Weather Research and Forecasting (HWRF)',
    387'72':'Hurricane Non-Hydrostatic Multiscale Model on the B Grid (HNMMB)',
    388'73':'Fog Forecast model - Ocean Prod. Center',
    389'74':'Gulf of America Wind/Wave',
    390'75':'Gulf of Alaska Wind/Wave',
    391'76':'Bias corrected Medium Range Forecast',
    392'77':'126 wave triangular, 28 layer Spectral model from GFS model',
    393'78':'126 wave triangular, 28 layer Spectral model from "Medium Range Forecast" run',
    394'79':'Reserved',
    395'80':'62 wave triangular, 28 layer Spectral model from "Medium Range Forecast" run',
    396'81':'Analysis from GFS (Global Forecast System)',
    397'82':'Analysis from GDAS (Global Data Assimilation System)',
    398'83':'High Resolution Rapid Refresh (HRRR)',
    399'84':'MESO NAM Model (currently 12 km)',
    400'85':'Real Time Ocean Forecast System (RTOFS)',
    401'86':'Early Hurricane Wind Speed Probability Model',
    402'87':'CAC Ensemble Forecasts from Spectral (ENSMB)',
    403'88':'NOAA Wave Watch III (NWW3) Ocean Wave Model',
    404'89':'Non-hydrostatic Meso Model (NMM) (Currently 8 km)',
    405'90':'62 wave triangular, 28 layer spectral model extension of the "Medium Range Forecast" run',
    406'91':'62 wave triangular, 28 layer spectral model extension of the GFS model',
    407'92':'62 wave triangular, 28 layer spectral model run from the "Medium Range Forecast" final analysis',
    408'93':'62 wave triangular, 28 layer spectral model run from the T62 GDAS analysis of the "Medium Range Forecast" run',
    409'94':'T170/L42 Global Spectral Model from MRF run',
    410'95':'T126/L42 Global Spectral Model from MRF run',
    411'96':'Global Forecast System Model T1534 - Forecast hours 00-384 T574 - Forecast hours 00-192 T190 - Forecast hours 204-384',
    412'97':'Global Chemistry and Aerosol Forecast System (GCAFS)',
    413'98':'Climate Forecast System Model -- Atmospheric model (GFS) coupled to a multi level ocean model . Currently GFS spectral model at T62, 64 levels coupled to 40 level MOM3 ocean model.',
    414'99':'Miscellaneous Test ID',
    415'100':'Miscellaneous Test ID',
    416'101':'Conventional Observation Re-Analysis (CORE)',
    417'102-103':'Reserved',
    418'104':'National Blend GRIB',
    419'105':'Rapid Refresh (RAP)',
    420'106':'Reserved',
    421'107':'Global Ensemble Forecast System (GEFS)',
    422'108':'Localized Aviation MOS Program (LAMP)',
    423'109':'Real Time Mesoscale Analysis (RTMA)',
    424'110':'NAM Model - 15km version',
    425'111':'NAM model, generic resolution (Used in SREF processing)',
    426'112':'WRF-NMM model, generic resolution (Used in various runs) NMM=Nondydrostatic Mesoscale Model (NCEP)',
    427'113':'Products from NCEP SREF processing',
    428'114':'NAEFS Products from joined NCEP, CMC global ensembles',
    429'115':'Downscaled GFS from NAM eXtension',
    430'116':'WRF-EM model, generic resolution (Used in various runs) EM - Eulerian Mass-core (NCAR - aka Advanced Research WRF)',
    431'117':'NEMS GFS Aerosol Component',
    432'118':'UnRestricted Mesoscale Analysis (URMA)',
    433'119':'WAM (Whole Atmosphere Model)',
    434'120':'Ice Concentration Analysis',
    435'121':'Western North Atlantic Regional Wave Model',
    436'122':'Alaska Waters Regional Wave Model',
    437'123':'North Atlantic Hurricane Wave Model',
    438'124':'Eastern North Pacific Regional Wave Model',
    439'125':'North Pacific Hurricane Wave Model',
    440'126':'Sea Ice Forecast Model',
    441'127':'Lake Ice Forecast Model',
    442'128':'Global Ocean Forecast Model',
    443'129':'Global Ocean Data Analysis System (GODAS)',
    444'130':'Merge of fields from the RUC, NAM, and Spectral Model',
    445'131':'Great Lakes Wave Model',
    446'132':'High Resolution Ensemble Forecast (HREF)',
    447'133':'Great Lakes Short Range Wave Model',
    448'134':'Rapid Refresh Forecast System (RRFS)',
    449'135':'Hurricane Analysis and Forecast System (HAFS)',
    450'136':'RRFS Ensemble Forecast System (REFS)',
    451'137':'Artificial Intelligence Global Forecast System (AIGFS)',
    452'138':'Artificial Intelligence Global Ensemble Forecast System (AIGEFS)',
    453'139':'Hybrid Global Ensemble Forecast System (HGEFS)',
    454'140':'North American Regional Reanalysis (NARR)',
    455'141':'Land Data Assimilation and Forecast System',
    456'142-149':'Reserved',
    457'150':'NWS River Forecast System (NWSRFS)',
    458'151':'NWS Flash Flood Guidance System (NWSFFGS)',
    459'152':'WSR-88D Stage II Precipitation Analysis',
    460'153':'WSR-88D Stage III Precipitation Analysis',
    461'154-179':'Reserved',
    462'180':'Quantitative Precipitation Forecast generated by NCEP',
    463'181':'River Forecast Center Quantitative Precipitation Forecast mosaic generated by NCEP',
    464'182':'River Forecast Center Quantitative Precipitation estimate mosaic generated by NCEP',
    465'183':'NDFD product generated by NCEP/HPC',
    466'184':'Climatological Calibrated Precipitation Analysis (CCPA)',
    467'185-189':'Reserved',
    468'190':'National Convective Weather Diagnostic generated by NCEP/AWC',
    469'191':'Current Icing Potential automated product genterated by NCEP/AWC',
    470'192':'Analysis product from NCEP/AWC',
    471'193':'Forecast product from NCEP/AWC',
    472'194':'Reserved',
    473'195':'Climate Data Assimilation System 2 (CDAS2)',
    474'196':'Climate Data Assimilation System 2 (CDAS2) - used for regeneration runs',
    475'197':'Climate Data Assimilation System (CDAS)',
    476'198':'Climate Data Assimilation System (CDAS) - used for regeneration runs',
    477'199':'Climate Forecast System Reanalysis (CFSR) -- Atmospheric model (GFS) coupled to a multi level ocean, land and seaice model. GFS spectral model at T382, 64 levels coupled to 40 level MOM4 ocean model.',
    478'200':'CPC Manual Forecast Product',
    479'201':'CPC Automated Product',
    480'202-209':'Reserved',
    481'210':'EPA Air Quality Forecast - Currently North East US domain',
    482'211':'EPA Air Quality Forecast - Currently Eastern US domain',
    483'212-214':'Reserved',
    484'215':'SPC Manual Forecast Product',
    485'216-219':'Reserved',
    486'220':'NCEP/OPC automated product',
    487'221-230':'Reserved for WPC products',
    488'231-254':'Reserved',
    489'255':'Missing',
    490}

table_originating_centers = {'1': 'Melbourne', '2': 'Melbourne', '3': 'Melbourne', '4': 'Moscow', '5': 'Moscow', '6': 'Moscow', '7': 'US National Weather Service - NCEP', '8': 'US National Weather Service Telecommunications Gateway (NWSTG)', '9': 'US National Weather Service - Other', '10': 'Cairo (RSMC)', '11': 'Cairo (RSMC)', '12': 'Dakar (RSMC)', '13': 'Dakar (RSMC)', '14': 'Nairobi (RSMC)', '15': 'Nairobi (RSMC)', '16': 'Casablanca (RSMC)', '17': 'Tunis (RSMC)', '18': 'Tunis-Casablanca (RSMC)', '19': 'Tunis-Casablanca (RSMC)', '20': 'Las Palmas', '21': 'Algiers (RSMC)', '22': 'ACMAD', '23': 'Mozambique (NMC)', '24': 'Pretoria (RSMC)', '25': 'La Réunion (RSMC)', '26': 'Khabarovsk (RSMC)', '27': 'Khabarovsk (RSMC)', '28': 'New Delhi (RSMC)', '29': 'New Delhi (RSMC)', '30': 'Novosibirsk (RSMC)', '31': 'Novosibirsk (RSMC)', '32': 'Tashkent (RSMC)', '33': 'Jeddah (RSMC)', '34': 'Tokyo (RSMC), Japan Meteorological Agency', '35': 'Tokyo (RSMC), Japan Meteorological Agency', '36': 'Bangkok', '37': 'Ulaanbaatar', '38': 'Beijing (RSMC)', '39': 'Beijing (RSMC)', '40': 'Seoul', '41': 'Buenos Aires (RSMC)', '42': 'Buenos Aires (RSMC)', '43': 'Brasilia (RSMC)', '44': 'Brasilia (RSMC)', '45': 'Santiago', '46': 'Brazilian Space Agency - INPE', '47': 'Colombia (NMC)', '48': 'Ecuador (NMC)', '49': 'Peru (NMC)', '50': 'Venezuela (Bolivarian Republic of) (NMC)', '51': 'Miami (RSMC)', '52': 'Miami (RSMC), National Hurricane Center', '53': 'MSC Monitoring', '54': 'Montreal (RSMC)', '55': 'San Francisco', '56': 'ARINC Center', '57': 'US Air Force - Air Force Global Weather Center', '58': 'Fleet Numerical Meteorology and Oceanography Center, Monterey, CA, US', '59': 'The NOAA Forecast Systems Laboratory, Boulder, CO, US', '60': 'United States National Center for Atmospheric Research (NCAR)', '61': 'Service ARGOS - Landover', '62': 'US Naval Oceanographic Office', '63': 'International Research Institute for Climate and Society (IRI)', '64': 'Honolulu (RSMC)', '65': 'Darwin (RSMC)', '66': 'Darwin (RSMC)', '67': 'Melbourne (RSMC)', '68': 'Reserved', '69': 'Wellington (RSMC)', '70': 'Wellington (RSMC)', '71': 'Nadi (RSMC)', '72': 'Singapore', '73': 'Malaysia (NMC)', '74': 'UK Meteorological Office - Exeter (RSMC)', '75': 'UK Meteorological Office - Exeter (RSMC)', '76': 'Moscow (RSMC)', '77': 'Reserved', '78': 'Offenbach (RSMC)', '79': 'Offenbach (RSMC)', '80': 'Rome (RSMC)', '81': 'Rome (RSMC)', '82': 'Norrköping', '83': 'Norrköping', '84': 'Toulouse (RSMC)', '85': 'Toulouse (RSMC)', '86': 'Helsinki', '87': 'Belgrade', '88': 'Oslo', '89': 'Prague', '90': 'Episkopi', '91': 'Ankara', '92': 'Frankfurt/Main', '93': 'London (WAFC)', '94': 'Copenhagen', '95': 'Rota', '96': 'Athens', '97': 'European Space Agency (ESA)', '98': 'European Center for Medium-Range Weather Forecasts (ECMWF) (RSMC)', '99': 'De Bilt', '100': 'Brazzaville', '101': 'Abidjan', '102': 'Libya (NMC)', '103': 'Madagascar (NMC)', '104': 'Mauritius (NMC)', '105': 'Niger (NMC)', '106': 'Seychelles (NMC)', '107': 'Uganda (NMC)', '108': 'United Republic of Tanzania (NMC)', '109': 'Zimbabwe (NMC)', '110': 'Hong Kong, China', '111': 'Afghanistan (NMC)', '112': 'Bahrain (NMC)', '113': 'Bangladesh (NMC)', '114': 'Bhutan (NMC)', '115': 'Cambodia (NMC)', '116': 'Democratic Peoples Republic of Korea (NMC)', '117': 'Islamic Republic of Iran (NMC)', '118': 'Iraq (NMC)', '119': 'Kazakhstan (NMC)', '120': 'Kuwait (NMC)', '121': 'Kyrgyzstan (NMC)', '122': 'Lao Peoples Democratic Republic (NMC)', '123': 'Macao, China', '124': 'Maldives (NMC)', '125': 'Myanmar (NMC)', '126': 'Nepal (NMC)', '127': 'Oman (NMC)', '128': 'Pakistan (NMC)', '129': 'Qatar (NMC)', '130': 'Yemen (NMC)', '131': 'Sri Lanka (NMC)', '132': 'Tajikistan (NMC)', '133': 'Turkmenistan (NMC)', '134': 'United Arab Emirates (NMC)', '135': 'Uzbekistan (NMC)', '136': 'Vietnam (NMC)', '137-139': 'Reserved', '140': 'Bolivia (Plurinational State of) (NMC)', '141': 'Guyana (NMC)', '142': 'Paraguay (NMC)', '143': 'Suriname (NMC)', '144': 'Uruguay (NMC)', '145': 'French Guiana', '146': 'Brazilian Navy Hydrographic Center', '147': 'National Commission on Space Activities (CONAE) - Argentina', '148': 'Brazilian Department of Airspace Control - DECEA', '149': 'Reserved', '150': 'Antigua and Barbuda (NMC)', '151': 'Bahamas (NMC)', '152': 'Barbados (NMC)', '153': 'Belize (NMC)', '154': 'British Caribbean Territories Center', '155': 'San José', '156': 'Cuba (NMC)', '157': 'Dominica (NMC)', '158': 'Dominican Republic (NMC)', '159': 'El Salvador (NMC)', '160': 'US NOAA/NESDIS', '161': 'US NOAA Office of Oceanic and Atmospheric Research', '162': 'Guatemala (NMC)', '163': 'Haiti (NMC)', '164': 'Honduras (NMC)', '165': 'Jamaica (NMC)', '166': 'Mexico City', '167': 'Curaçao and Sint Maarten (NMC)', '168': 'Nicaragua (NMC)', '169': 'Panama (NMC)', '170': 'Saint Lucia (NMC)', '171': 'Trinidad and Tobago (NMC)', '172': 'French Departments in RA IV', '173': 'US National Aeronautics and Space Administration (NASA)', '174': 'Integrated System Data Management/ Marine Environmental Data Service (ISDM/MEDS) - Canada', '175': 'University Corporation for Atmospheric Research (UCAR) - US', '176': 'Cooperative Institude for Meteorological Satellite Studies (CIMMS) - US', '177': 'NOAA National Ocean Service - US', '178': 'Spire Global, Inc.', '179': 'GeoOptics, Inc.', '180': 'PlanetiQ', '181': 'Atmospheric and Environmental Research (AER)', '182': 'tomorrow.io', '183': 'Scripps Institute of Oceanography (UC San Diego - US)', '184-189': 'Reserved', '190': 'Cook Islands (NMC)', '191': 'French Polynesia (NMC)', '192': 'Tonga (NMC)', '193': 'Vanuatu (NMC)', '194': 'Brunei Darussalam (NMC)', '195': 'Indonesia (NMC)', '196': 'Kiribati (NMC)', '197': 'Federated States of Micronesia (NMC)', '198': 'New Caledonia (NMC)', '199': 'Niue', '200': 'Papua New Guinea (NMC)', '201': 'Philippines (NMC)', '202': 'Samoa (NMC)', '203': 'Solomon Islands (NMC)', '204': 'National Institude of Water and Atmospheric Research (NIWA - New Zealand)', '205-209': 'Reserved', '210': 'Frascati (ESA/ESRIN)', '211': 'Lannion', '212': 'Lisbon', '213': 'Reykjavik', '214': 'Madrid', '215': 'Zurich', '216': 'Service ARGOS - Toulouse', '217': 'Bratislava', '218': 'Budapest', '219': 'Ljubljana', '220': 'Warsaw', '221': 'Zagreb', '222': 'Albania (NMC)', '223': 'Armenia (NMC)', '224': 'Austria (NMC)', '225': 'Azerbaijan (NMC)', '226': 'Belarus (NMC)', '227': 'Belgium (NMC)', '228': 'Bosnia and Herzegovina (NMC)', '229': 'Bulgaria (NMC)', '230': 'Cyprus (NMC)', '231': 'Estonia (NMC)', '232': 'Georgia (NMC)', '233': 'Dublin', '234': 'Israel (NMC)', '235': 'Jordan (NMC)', '236': 'Latvia (NMC)', '237': 'Lebanon (NMC)', '238': 'Lithuania (NMC)', '239': 'Luxembourg', '240': 'Malta (NMC)', '241': 'Monaco', '242': 'Romania (NMC)', '243': 'Syrian Arab Republic (NMC)', '244': 'The former Yugoslav Republic of Macedonia (NMC)', '245': 'Ukraine (NMC)', '246': 'Republic of Moldova (NMC)', '247': 'Operational Programme for the Exchange of weather RAdar information (OPERA) - EUMETNET', '248': 'Montenegro (NMC)', '249': 'Barcelona Dust Forecast Center', '250': 'COnsortium for Small scale MOdelling (COSMO)', '251': 'Meteorological Cooperation on Operational NWP (MetCoOp)', '252': 'Max Planck Institute for Meteorology (MPI-M)', '253': 'Alfred Wegener Institute', '254': 'EUMETSAT Operation Center', '255': 'Not to be Used', '256': 'Angola (NMC)', '257': 'Benin (NMC)', '258': 'Botswana (NMC)', '259': 'Burkina Faso (NMC)', '260': 'Burundi (NMC)', '261': 'Cameroon (NMC)', '262': 'Cabo Verde (NMC)', '263': 'Central African Republic (NMC)', '264': 'Chad (NMC)', '265': 'Comoros (NMC)', '266': 'Democratic Republic of the Congo (NMC)', '267': 'Djibouti (NMC)', '268': 'Eritrea (NMC)', '269': 'Ethiopia (NMC)', '270': 'Gabon (NMC)', '271': 'The Gambia (NMC)', '272': 'Ghana (NMC)', '273': 'Guinea (NMC)', '274': 'Guinea-Bissau (NMC)', '275': 'Lesotho (NMC)', '276': 'Liberia (NMC)', '277': 'Malawi (NMC)', '278': 'Mali (NMC)', '279': 'Mauritania (NMC)', '280': 'Namibia (NMC)', '281': 'Nigeria (NMC)', '282': 'Rwanda (NMC)', '283': 'São Tomé and Príncipe (NMC)', '284': 'Sierra Leone (NMC)', '285': 'Somalia (NMC)', '286': 'Sudan (NMC)', '287': 'Eswatini (NMC)', '288': 'Togo (NMC)', '289': 'Zambia (NMC)', '290': 'EUMETNET E-Profile', '291': 'Institute of Atmospheric Physics (IAP) of the Chinese Academy of Sciences (CAS)', '292': 'Helmholtz Centre for Environmental Research (UFZ)', '293': 'University of Bremen', '294': 'Netherlands Institute for Space Research (SRON)', '295': 'Royal Belgian Institute for Space Aeronomy (BIRA-IASB)', '296': 'French National Centre for Scientific Research (CNRS)', '297': 'Nanjing Institute of Environmental Sciences (NIES)', '298': 'Dynamic Meteorology Laboratory (LMD)', '299': 'The Rutherford Appleton Laboratory (RAL)', '300': 'Greek Atomic Energy Commission (Greece)', '301': 'United States Environmental Protection Agency (USA)', '302': 'Australian Radiation Protection and Nuclear Safety (Australia)', '303': 'Authority for Nuclear Safety and Radiation Protection (Kingdom of the Netherlands)', '304': 'Autorité de sûreté nucléaire (France)', '305': 'Bundesamt für Strahlenschutz (Germany)', '306': 'National Commission for Nuclear Activities Control (Romania)', '307': 'Consejo de Seguridad Nuclear (Spain)', '308': 'Danish Emergency Management Agency (Denmark)', '309': 'Norwegian Radiation Protection Agency (Norway)', '310': 'Federal Agency for Nuclear Control (Belgium)', '311': 'Institute of Radiation Protection and Dosimetry (Brazil)', '312': 'National Inspectorate for Nuclear Safety and Radiation Protection (Italy)', '313': 'Nuclear Regulatory Authority (Turkey)', '314': 'Nuclear Regulation Authority (Japan)', '315': 'Nuclear Regulatory Authority (Bulgaria)', '316': 'Ukrainian Radiation Protection Institute (Ukraine)', '317': 'Health Canada Radio Protection Bureau (Canada)', '318': 'Portuguese Society for Radiation Protection (Portugal)', '319': 'Swedish Radiation Safety Authority (Sweden)', '320': 'Radiation and Nuclear Safety Authority (Finland)', '321': 'State Office for Nuclear Safety (Czech Republic)', '322': 'Nuclear Regulation Authority (Slovakia)', '323-65534': 'Reserved', '65535': 'Missing Value'}
table_originating_subcenters = {'1': 'NCEP Re-Analysis Project', '2': 'NCEP Ensemble Products', '3': 'NCEP Central Operations', '4': 'Environmental Modeling Center', '5': 'Weather Prediction Center', '6': 'Ocean Prediction Center', '7': 'Climate Prediction Center', '8': 'Aviation Weather Center', '9': 'Storm Prediction Center', '10': 'National Hurricane Center', '11': 'NWS Techniques Development Laboratory', '12': 'NESDIS Office of Research and Applications', '13': 'Federal Aviation Administration', '14': 'NWS Meteorological Development Laboratory', '15': 'North American Regional Reanalysis Project', '16': 'Space Weather Prediction Center', '17': 'ESRL Global Systems Division', '18': 'National Water Center'}
table_generating_process = {'0-1': 'Reserved', '2': 'Ultra Violet Index Model', '3': 'NCEP/ARL Transport and Dispersion Model', '4': 'NCEP/ARL Smoke Model', '5': 'Satellite Derived Precipitation and temperatures, from IR (See PDS Octet 41 ... for specific satellite ID)', '6': 'NCEP/ARL Dust Model', '7-9': 'Reserved', '10': 'Global Wind-Wave Forecast Model', '11': 'Global Multi-Grid Wave Model (Static Grids)', '12': 'Probabilistic Storm Surge (P-Surge)', '13': 'Hurricane Multi-Grid Wave Model', '14': 'Extra-tropical Storm Surge Atlantic Domain', '15': 'Nearshore Wave Prediction System (NWPS)', '16': 'Extra-Tropical Storm Surge (ETSS)', '17': 'Extra-tropical Storm Surge Pacific Domain', '18': 'Probabilistic Extra-Tropical Storm Surge (P-ETSS)', '19': 'Reserved', '20': 'Extra-tropical Storm Surge Micronesia Domain', '21': 'Extra-tropical Storm Surge Atlantic Domain (3D)', '22': 'Extra-tropical Storm Surge Pacific Domain (3D)', '23': 'Extra-tropical Storm Surge Micronesia Domain (3D)', '24': 'Reserved', '25': 'Snow Cover Analysis', '26-29': 'Reserved', '30': 'Forecaster generated field', '31': 'Value added post processed field', '32-41': 'Reserved', '42': 'Global Optimum Interpolation Analysis (GOI) from GFS model', '43': 'Global Optimum Interpolation Analysis (GOI) from "Final" run', '44': 'Sea Surface Temperature Analysis', '45': 'Coastal Ocean Circulation Model', '46': 'HYCOM - Global', '47': 'HYCOM - North Pacific basin', '48': 'HYCOM - North Atlantic basin', '49': 'Ozone Analysis from TIROS Observations', '50-51': 'Reserved', '52': 'Ozone Analysis from Nimbus 7 Observations', '53': 'Flood Hazard Outlook Forecast generated by NWC', '54': 'Area Hydrologic Discussion Forecast generated by NWC', '55-63': 'Reserved', '64': 'Regional Optimum Interpolation Analysis (ROI)', '65-67': 'Reserved', '68': '80 wave triangular, 18-layer Spectral model from GFS model', '69': '80 wave triangular, 18 layer Spectral model from "Medium Range Forecast" run', '70': 'Quasi-Lagrangian Hurricane Model (QLM)', '71': 'Hurricane Weather Research and Forecasting (HWRF)', '72': 'Hurricane Non-Hydrostatic Multiscale Model on the B Grid (HNMMB)', '73': 'Fog Forecast model - Ocean Prod. Center', '74': 'Gulf of America Wind/Wave', '75': 'Gulf of Alaska Wind/Wave', '76': 'Bias corrected Medium Range Forecast', '77': '126 wave triangular, 28 layer Spectral model from GFS model', '78': '126 wave triangular, 28 layer Spectral model from "Medium Range Forecast" run', '79': 'Reserved', '80': '62 wave triangular, 28 layer Spectral model from "Medium Range Forecast" run', '81': 'Analysis from GFS (Global Forecast System)', '82': 'Analysis from GDAS (Global Data Assimilation System)', '83': 'High Resolution Rapid Refresh (HRRR)', '84': 'MESO NAM Model (currently 12 km)', '85': 'Real Time Ocean Forecast System (RTOFS)', '86': 'Early Hurricane Wind Speed Probability Model', '87': 'CAC Ensemble Forecasts from Spectral (ENSMB)', '88': 'NOAA Wave Watch III (NWW3) Ocean Wave Model', '89': 'Non-hydrostatic Meso Model (NMM) (Currently 8 km)', '90': '62 wave triangular, 28 layer spectral model extension of the "Medium Range Forecast" run', '91': '62 wave triangular, 28 layer spectral model extension of the GFS model', '92': '62 wave triangular, 28 layer spectral model run from the "Medium Range Forecast" final analysis', '93': '62 wave triangular, 28 layer spectral model run from the T62 GDAS analysis of the "Medium Range Forecast" run', '94': 'T170/L42 Global Spectral Model from MRF run', '95': 'T126/L42 Global Spectral Model from MRF run', '96': 'Global Forecast System Model T1534 - Forecast hours 00-384 T574 - Forecast hours 00-192 T190 - Forecast hours 204-384', '97': 'Global Chemistry and Aerosol Forecast System (GCAFS)', '98': 'Climate Forecast System Model -- Atmospheric model (GFS) coupled to a multi level ocean model . Currently GFS spectral model at T62, 64 levels coupled to 40 level MOM3 ocean model.', '99': 'Miscellaneous Test ID', '100': 'Miscellaneous Test ID', '101': 'Conventional Observation Re-Analysis (CORE)', '102-103': 'Reserved', '104': 'National Blend GRIB', '105': 'Rapid Refresh (RAP)', '106': 'Reserved', '107': 'Global Ensemble Forecast System (GEFS)', '108': 'Localized Aviation MOS Program (LAMP)', '109': 'Real Time Mesoscale Analysis (RTMA)', '110': 'NAM Model - 15km version', '111': 'NAM model, generic resolution (Used in SREF processing)', '112': 'WRF-NMM model, generic resolution (Used in various runs) NMM=Nondydrostatic Mesoscale Model (NCEP)', '113': 'Products from NCEP SREF processing', '114': 'NAEFS Products from joined NCEP, CMC global ensembles', '115': 'Downscaled GFS from NAM eXtension', '116': 'WRF-EM model, generic resolution (Used in various runs) EM - Eulerian Mass-core (NCAR - aka Advanced Research WRF)', '117': 'NEMS GFS Aerosol Component', '118': 'UnRestricted Mesoscale Analysis (URMA)', '119': 'WAM (Whole Atmosphere Model)', '120': 'Ice Concentration Analysis', '121': 'Western North Atlantic Regional Wave Model', '122': 'Alaska Waters Regional Wave Model', '123': 'North Atlantic Hurricane Wave Model', '124': 'Eastern North Pacific Regional Wave Model', '125': 'North Pacific Hurricane Wave Model', '126': 'Sea Ice Forecast Model', '127': 'Lake Ice Forecast Model', '128': 'Global Ocean Forecast Model', '129': 'Global Ocean Data Analysis System (GODAS)', '130': 'Merge of fields from the RUC, NAM, and Spectral Model', '131': 'Great Lakes Wave Model', '132': 'High Resolution Ensemble Forecast (HREF)', '133': 'Great Lakes Short Range Wave Model', '134': 'Rapid Refresh Forecast System (RRFS)', '135': 'Hurricane Analysis and Forecast System (HAFS)', '136': 'RRFS Ensemble Forecast System (REFS)', '137': 'Artificial Intelligence Global Forecast System (AIGFS)', '138': 'Artificial Intelligence Global Ensemble Forecast System (AIGEFS)', '139': 'Hybrid Global Ensemble Forecast System (HGEFS)', '140': 'North American Regional Reanalysis (NARR)', '141': 'Land Data Assimilation and Forecast System', '142-149': 'Reserved', '150': 'NWS River Forecast System (NWSRFS)', '151': 'NWS Flash Flood Guidance System (NWSFFGS)', '152': 'WSR-88D Stage II Precipitation Analysis', '153': 'WSR-88D Stage III Precipitation Analysis', '154-179': 'Reserved', '180': 'Quantitative Precipitation Forecast generated by NCEP', '181': 'River Forecast Center Quantitative Precipitation Forecast mosaic generated by NCEP', '182': 'River Forecast Center Quantitative Precipitation estimate mosaic generated by NCEP', '183': 'NDFD product generated by NCEP/HPC', '184': 'Climatological Calibrated Precipitation Analysis (CCPA)', '185-189': 'Reserved', '190': 'National Convective Weather Diagnostic generated by NCEP/AWC', '191': 'Current Icing Potential automated product genterated by NCEP/AWC', '192': 'Analysis product from NCEP/AWC', '193': 'Forecast product from NCEP/AWC', '194': 'Reserved', '195': 'Climate Data Assimilation System 2 (CDAS2)', '196': 'Climate Data Assimilation System 2 (CDAS2) - used for regeneration runs', '197': 'Climate Data Assimilation System (CDAS)', '198': 'Climate Data Assimilation System (CDAS) - used for regeneration runs', '199': 'Climate Forecast System Reanalysis (CFSR) -- Atmospheric model (GFS) coupled to a multi level ocean, land and seaice model. GFS spectral model at T382, 64 levels coupled to 40 level MOM4 ocean model.', '200': 'CPC Manual Forecast Product', '201': 'CPC Automated Product', '202-209': 'Reserved', '210': 'EPA Air Quality Forecast - Currently North East US domain', '211': 'EPA Air Quality Forecast - Currently Eastern US domain', '212-214': 'Reserved', '215': 'SPC Manual Forecast Product', '216-219': 'Reserved', '220': 'NCEP/OPC automated product', '221-230': 'Reserved for WPC products', '231-254': 'Reserved', '255': 'Missing'}